package net.pingex.dcf.core;

import org.apache.commons.configuration2.ConfigurationUtils;
import org.apache.commons.configuration2.FileBasedConfiguration;
import org.apache.commons.configuration2.ImmutableConfiguration;
import org.apache.commons.configuration2.PropertiesConfiguration;
import org.apache.commons.configuration2.builder.FileBasedConfigurationBuilder;
import org.apache.commons.configuration2.builder.fluent.Parameters;
import org.apache.commons.configuration2.ex.ConfigurationException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * Configuration manager
 */
public class Configuration
{
	/**
	 * File name to look for
	 */
	private static final String FILENAME = "dcf.properties";
	private static final Logger LOGGER = LogManager.getLogger(Configuration.class);

	/**
	 * Main configuration store
	 */
	private static org.apache.commons.configuration2.Configuration store;

	/**
	 * Load configuration file
	 */
	public static void load()
	{
		try
		{
			LOGGER.info("Loading configuration file");
			store = new FileBasedConfigurationBuilder<FileBasedConfiguration>(PropertiesConfiguration.class)
					.configure(new Parameters().fileBased().setFileName(FILENAME))
					.getConfiguration();
		} catch (ConfigurationException e)
		{
			LOGGER.fatal("Failed to load configuration", e);
		}
	}

	/**
	 * Get the store in read-only mode
	 * @return The read-only store
	 */
	public static ImmutableConfiguration getStore()
	{
		return ConfigurationUtils.unmodifiableConfiguration(store);
	}

	// ========================================

	/**
	 * Bot display name
	 */
	public static String BOT_NAME = "DCF-enabled Bot";


	/**
	 * Load config keys
	 */
	public static void init()
	{
		BOT_NAME = store.getString("general.bot_name", BOT_NAME);
	}
}
